@@ -535,6 +535,7 @@ setClass("rlmerMod",
                         b.s       = "numeric",
                         devcomp = "list",
                         pp      = "rlmerPredD",
+                        optinfo = "list",
                         ## from rlmerResp:
                         rho.e   = "psi_func",
                         rho.sigma.e = "psi_func",
@@ -721,6 +722,7 @@ setClass("rlmerMod",
               b.s=u,
               devcomp=devcomp,
               pp=pp,
+              optinfo=list(),
               rho.e=cPsi,
               rho.sigma.e=cPsi,
               method="DAS",
